==> haskell-skylighting-0.14.3-16-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting
version:              0.14.3
visibility:           public
id:                   skylighting-0.14.3-v6qfnt4yoq3ZY4MtMNSf8
key:                  skylighting-0.14.3-v6qfnt4yoq3ZY4MtMNSf8
license:              GPL-2.0-only
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.

category:             Text
abi:                  eceec1c4c7317b7c058e78020bce9df1
exposed:              True
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-format-ansi-0.1-4uUy0xDmmKzXdJU99LoTT:Skylighting.Format.ANSI,
    Skylighting.Format.ConTeXt from skylighting-format-context-0.1.0.2-GrBZl2gymZNGWuoQQRaziS:Skylighting.Format.ConTeXt,
    Skylighting.Format.HTML from skylighting-format-blaze-html-0.1.1.3-5vL2xZYU7MO5NzGplp7EpS:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-format-latex-0.1-8KUzTwYUJ8z1YDNm3yTUKd:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv:Skylighting.Types

hidden-modules:
    Skylighting.Syntax.Abc Skylighting.Syntax.Actionscript
    Skylighting.Syntax.Ada Skylighting.Syntax.Agda
    Skylighting.Syntax.Alert Skylighting.Syntax.Apache
    Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
    Skylighting.Syntax.Ats Skylighting.Syntax.Awk
    Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
    Skylighting.Syntax.Boo Skylighting.Syntax.C
    Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
    Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
    Skylighting.Syntax.Coldfusion Skylighting.Syntax.Comments
    Skylighting.Syntax.Commonlisp Skylighting.Syntax.Cpp
    Skylighting.Syntax.Crystal Skylighting.Syntax.Cs
    Skylighting.Syntax.Css Skylighting.Syntax.Curry
    Skylighting.Syntax.D Skylighting.Syntax.Dart
    Skylighting.Syntax.Debiancontrol Skylighting.Syntax.Default
    Skylighting.Syntax.Diff Skylighting.Syntax.Djangotemplate
    Skylighting.Syntax.Dockerfile Skylighting.Syntax.Dosbat
    Skylighting.Syntax.Dot Skylighting.Syntax.Doxygen
    Skylighting.Syntax.Doxygenlua Skylighting.Syntax.Dtd
    Skylighting.Syntax.Eiffel Skylighting.Syntax.Elixir
    Skylighting.Syntax.Elm Skylighting.Syntax.Email
    Skylighting.Syntax.Erlang Skylighting.Syntax.Fasm
    Skylighting.Syntax.FortranFixed Skylighting.Syntax.FortranFree
    Skylighting.Syntax.Fsharp Skylighting.Syntax.Gap
    Skylighting.Syntax.Gcc Skylighting.Syntax.Glsl
    Skylighting.Syntax.Gnuassembler Skylighting.Syntax.Go
    Skylighting.Syntax.Gpr Skylighting.Syntax.Graphql
    Skylighting.Syntax.Groovy Skylighting.Syntax.Hamlet
    Skylighting.Syntax.Haskell Skylighting.Syntax.Haxe
    Skylighting.Syntax.Html Skylighting.Syntax.Idris
    Skylighting.Syntax.Ini Skylighting.Syntax.Isocpp
    Skylighting.Syntax.J Skylighting.Syntax.Java
    Skylighting.Syntax.Javadoc Skylighting.Syntax.Javascript
    Skylighting.Syntax.JavascriptReact Skylighting.Syntax.Json
    Skylighting.Syntax.Jsp Skylighting.Syntax.Julia
    Skylighting.Syntax.Kotlin Skylighting.Syntax.Latex
    Skylighting.Syntax.Lex Skylighting.Syntax.Lilypond
    Skylighting.Syntax.LiterateCurry Skylighting.Syntax.LiterateHaskell
    Skylighting.Syntax.Llvm Skylighting.Syntax.Lua
    Skylighting.Syntax.M4 Skylighting.Syntax.Makefile
    Skylighting.Syntax.Mandoc Skylighting.Syntax.Markdown
    Skylighting.Syntax.Mathematica Skylighting.Syntax.Matlab
    Skylighting.Syntax.Maxima Skylighting.Syntax.Mediawiki
    Skylighting.Syntax.Metafont Skylighting.Syntax.Mips
    Skylighting.Syntax.Modelines Skylighting.Syntax.Modula2
    Skylighting.Syntax.Modula3 Skylighting.Syntax.Monobasic
    Skylighting.Syntax.Mustache Skylighting.Syntax.Nasm
    Skylighting.Syntax.Nim Skylighting.Syntax.Nix
    Skylighting.Syntax.Noweb Skylighting.Syntax.Objectivec
    Skylighting.Syntax.Objectivecpp Skylighting.Syntax.Ocaml
    Skylighting.Syntax.Octave Skylighting.Syntax.Opencl
    Skylighting.Syntax.Orgmode Skylighting.Syntax.Pascal
    Skylighting.Syntax.Perl Skylighting.Syntax.Php
    Skylighting.Syntax.Pike Skylighting.Syntax.Postscript
    Skylighting.Syntax.Povray Skylighting.Syntax.Powershell
    Skylighting.Syntax.Prolog Skylighting.Syntax.Protobuf
    Skylighting.Syntax.Pure Skylighting.Syntax.Purebasic
    Skylighting.Syntax.Purescript Skylighting.Syntax.Python
    Skylighting.Syntax.Qml Skylighting.Syntax.R
    Skylighting.Syntax.Racket Skylighting.Syntax.Raku
    Skylighting.Syntax.Relaxng Skylighting.Syntax.Relaxngcompact
    Skylighting.Syntax.Rest Skylighting.Syntax.Rhtml
    Skylighting.Syntax.Roff Skylighting.Syntax.Ruby
    Skylighting.Syntax.Rust Skylighting.Syntax.Sass
    Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
    Skylighting.Syntax.Sci Skylighting.Syntax.Scss
    Skylighting.Syntax.Sed Skylighting.Syntax.Sgml
    Skylighting.Syntax.Sml Skylighting.Syntax.SpdxComments
    Skylighting.Syntax.Sql Skylighting.Syntax.SqlMysql
    Skylighting.Syntax.SqlPostgresql Skylighting.Syntax.Stan
    Skylighting.Syntax.Stata Skylighting.Syntax.Swift
    Skylighting.Syntax.Systemverilog Skylighting.Syntax.Tcl
    Skylighting.Syntax.Tcsh Skylighting.Syntax.Terraform
    Skylighting.Syntax.Texinfo Skylighting.Syntax.Toml
    Skylighting.Syntax.Typescript Skylighting.Syntax.Verilog
    Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
    Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
    Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
    Skylighting.Syntax.Yaml Skylighting.Syntax.Zig
    Skylighting.Syntax.Zsh

import-dirs:          /usr/lib/ghc-9.6.6/site-local/skylighting-0.14.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/skylighting-0.14.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/skylighting-0.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting
hs-libraries:         HSskylighting-0.14.3-v6qfnt4yoq3ZY4MtMNSf8
depends:
    base-4.18.2.1 binary-0.8.9.1 containers-0.6.7
    skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv
    skylighting-format-ansi-0.1-4uUy0xDmmKzXdJU99LoTT
    skylighting-format-blaze-html-0.1.1.3-5vL2xZYU7MO5NzGplp7EpS
    skylighting-format-context-0.1.0.2-GrBZl2gymZNGWuoQQRaziS
    skylighting-format-latex-0.1-8KUzTwYUJ8z1YDNm3yTUKd

haddock-interfaces:   /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html:         /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-0.14.3-18-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting
version:              0.14.3
visibility:           public
id:                   skylighting-0.14.3-AFjprEBMEWgB4aVqA4d61N
key:                  skylighting-0.14.3-AFjprEBMEWgB4aVqA4d61N
license:              GPL-2.0-only
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.

category:             Text
abi:                  8cfe26dc14f9fb0ad9062d3b190b5a3c
exposed:              True
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.14.3-6ZvJN2No0Oj3j9qCnjgXmz:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-format-ansi-0.1-8Cjr0rW3h31DKwFaoqGbqQ:Skylighting.Format.ANSI,
    Skylighting.Format.ConTeXt from skylighting-format-context-0.1.0.2-Eqoh4Ki0ip8AicjHZmXcjd:Skylighting.Format.ConTeXt,
    Skylighting.Format.HTML from skylighting-format-blaze-html-0.1.1.3-C0xou1EgSZ7HE3dtIidh5X:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-format-latex-0.1-FM48DjQS6ByCfC7veMPbZQ:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.14.3-6ZvJN2No0Oj3j9qCnjgXmz:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.14.3-6ZvJN2No0Oj3j9qCnjgXmz:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.14.3-6ZvJN2No0Oj3j9qCnjgXmz:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.14.3-6ZvJN2No0Oj3j9qCnjgXmz:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.14.3-6ZvJN2No0Oj3j9qCnjgXmz:Skylighting.Types

hidden-modules:
    Skylighting.Syntax.Abc Skylighting.Syntax.Actionscript
    Skylighting.Syntax.Ada Skylighting.Syntax.Agda
    Skylighting.Syntax.Alert Skylighting.Syntax.Apache
    Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
    Skylighting.Syntax.Ats Skylighting.Syntax.Awk
    Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
    Skylighting.Syntax.Boo Skylighting.Syntax.C
    Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
    Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
    Skylighting.Syntax.Coldfusion Skylighting.Syntax.Comments
    Skylighting.Syntax.Commonlisp Skylighting.Syntax.Cpp
    Skylighting.Syntax.Crystal Skylighting.Syntax.Cs
    Skylighting.Syntax.Css Skylighting.Syntax.Curry
    Skylighting.Syntax.D Skylighting.Syntax.Dart
    Skylighting.Syntax.Debiancontrol Skylighting.Syntax.Default
    Skylighting.Syntax.Diff Skylighting.Syntax.Djangotemplate
    Skylighting.Syntax.Dockerfile Skylighting.Syntax.Dosbat
    Skylighting.Syntax.Dot Skylighting.Syntax.Doxygen
    Skylighting.Syntax.Doxygenlua Skylighting.Syntax.Dtd
    Skylighting.Syntax.Eiffel Skylighting.Syntax.Elixir
    Skylighting.Syntax.Elm Skylighting.Syntax.Email
    Skylighting.Syntax.Erlang Skylighting.Syntax.Fasm
    Skylighting.Syntax.FortranFixed Skylighting.Syntax.FortranFree
    Skylighting.Syntax.Fsharp Skylighting.Syntax.Gap
    Skylighting.Syntax.Gcc Skylighting.Syntax.Glsl
    Skylighting.Syntax.Gnuassembler Skylighting.Syntax.Go
    Skylighting.Syntax.Gpr Skylighting.Syntax.Graphql
    Skylighting.Syntax.Groovy Skylighting.Syntax.Hamlet
    Skylighting.Syntax.Haskell Skylighting.Syntax.Haxe
    Skylighting.Syntax.Html Skylighting.Syntax.Idris
    Skylighting.Syntax.Ini Skylighting.Syntax.Isocpp
    Skylighting.Syntax.J Skylighting.Syntax.Java
    Skylighting.Syntax.Javadoc Skylighting.Syntax.Javascript
    Skylighting.Syntax.JavascriptReact Skylighting.Syntax.Json
    Skylighting.Syntax.Jsp Skylighting.Syntax.Julia
    Skylighting.Syntax.Kotlin Skylighting.Syntax.Latex
    Skylighting.Syntax.Lex Skylighting.Syntax.Lilypond
    Skylighting.Syntax.LiterateCurry Skylighting.Syntax.LiterateHaskell
    Skylighting.Syntax.Llvm Skylighting.Syntax.Lua
    Skylighting.Syntax.M4 Skylighting.Syntax.Makefile
    Skylighting.Syntax.Mandoc Skylighting.Syntax.Markdown
    Skylighting.Syntax.Mathematica Skylighting.Syntax.Matlab
    Skylighting.Syntax.Maxima Skylighting.Syntax.Mediawiki
    Skylighting.Syntax.Metafont Skylighting.Syntax.Mips
    Skylighting.Syntax.Modelines Skylighting.Syntax.Modula2
    Skylighting.Syntax.Modula3 Skylighting.Syntax.Monobasic
    Skylighting.Syntax.Mustache Skylighting.Syntax.Nasm
    Skylighting.Syntax.Nim Skylighting.Syntax.Nix
    Skylighting.Syntax.Noweb Skylighting.Syntax.Objectivec
    Skylighting.Syntax.Objectivecpp Skylighting.Syntax.Ocaml
    Skylighting.Syntax.Octave Skylighting.Syntax.Opencl
    Skylighting.Syntax.Orgmode Skylighting.Syntax.Pascal
    Skylighting.Syntax.Perl Skylighting.Syntax.Php
    Skylighting.Syntax.Pike Skylighting.Syntax.Postscript
    Skylighting.Syntax.Povray Skylighting.Syntax.Powershell
    Skylighting.Syntax.Prolog Skylighting.Syntax.Protobuf
    Skylighting.Syntax.Pure Skylighting.Syntax.Purebasic
    Skylighting.Syntax.Purescript Skylighting.Syntax.Python
    Skylighting.Syntax.Qml Skylighting.Syntax.R
    Skylighting.Syntax.Racket Skylighting.Syntax.Raku
    Skylighting.Syntax.Relaxng Skylighting.Syntax.Relaxngcompact
    Skylighting.Syntax.Rest Skylighting.Syntax.Rhtml
    Skylighting.Syntax.Roff Skylighting.Syntax.Ruby
    Skylighting.Syntax.Rust Skylighting.Syntax.Sass
    Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
    Skylighting.Syntax.Sci Skylighting.Syntax.Scss
    Skylighting.Syntax.Sed Skylighting.Syntax.Sgml
    Skylighting.Syntax.Sml Skylighting.Syntax.SpdxComments
    Skylighting.Syntax.Sql Skylighting.Syntax.SqlMysql
    Skylighting.Syntax.SqlPostgresql Skylighting.Syntax.Stan
    Skylighting.Syntax.Stata Skylighting.Syntax.Swift
    Skylighting.Syntax.Systemverilog Skylighting.Syntax.Tcl
    Skylighting.Syntax.Tcsh Skylighting.Syntax.Terraform
    Skylighting.Syntax.Texinfo Skylighting.Syntax.Toml
    Skylighting.Syntax.Typescript Skylighting.Syntax.Verilog
    Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
    Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
    Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
    Skylighting.Syntax.Yaml Skylighting.Syntax.Zig
    Skylighting.Syntax.Zsh

import-dirs:          /usr/lib/ghc-9.6.6/site-local/skylighting-0.14.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/skylighting-0.14.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/skylighting-0.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting
hs-libraries:         HSskylighting-0.14.3-AFjprEBMEWgB4aVqA4d61N
depends:
    base-4.18.2.1 binary-0.8.9.1 containers-0.6.7
    skylighting-core-0.14.3-6ZvJN2No0Oj3j9qCnjgXmz
    skylighting-format-ansi-0.1-8Cjr0rW3h31DKwFaoqGbqQ
    skylighting-format-blaze-html-0.1.1.3-C0xou1EgSZ7HE3dtIidh5X
    skylighting-format-context-0.1.0.2-Eqoh4Ki0ip8AicjHZmXcjd
    skylighting-format-latex-0.1-FM48DjQS6ByCfC7veMPbZQ

haddock-interfaces:   /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html:         /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
